..
    Copyright (C) 2020 CERN.

    Docker-Services-CLI is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.

===================
Docker-Services-CLI
===================

.. image:: https://github.com/inveniosoftware/docker-services-cli/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/docker-services-cli/actions?query=workflow%3ACI


Python module to start external services needed to tests Invenio modules and applications.
